@@ -7,12 +7,21 @@ icon_import_setup_backend_selection = icon_tag_create = Icon(
 icon_import_setup_delete = Icon(driver_name='fontawesome', symbol='times')
 
 icon_import_setup_edit = Icon(driver_name='fontawesome', symbol='pencil-alt')
-icon_import_setup_execute = Icon(
+icon_import_setup_process = Icon(
     driver_name='fontawesome', symbol='play'
 )
-icon_import_setup_items_clear = Icon(
+icon_import_setup_item_delete = Icon(
+    driver_name='fontawesome', symbol='times'
+)
+icon_import_setup_item_process = Icon(
+    driver_name='fontawesome', symbol='play'
+)
+icon_import_setup_clear = Icon(
     driver_name='fontawesome', symbol='eraser'
 )
+icon_import_setup_items_list = Icon(
+    driver_name='fontawesome', symbol='file-upload'
+)
 icon_import_setup_list = Icon(
     driver_name='fontawesome', symbol='cloud-upload-alt'
 )
