@@ -13,8 +13,8 @@ permission_import_setup_delete = namespace.add_permission(
 permission_import_setup_edit = namespace.add_permission(
     label=_('Edit import setups'), name='import_setup_edit'
 )
-permission_import_setup_execute = namespace.add_permission(
-    label=_('Execute import setups'), name='import_setup_execute'
+permission_import_setup_process = namespace.add_permission(
+    label=_('Process import setups'), name='import_setup_process'
 )
 permission_import_setup_view = namespace.add_permission(
     label=_('View import setups'), name='import_setup_view'
