@@ -8,8 +8,12 @@ queue_importer = CeleryQueue(
 )
 
 queue_importer.add_task_type(
-    label=_('Execute an import setup'),
-    dotted_path='importer.tasks.task_import_setup_execute'
+    label=_('Process an import setup'),
+    dotted_path='importer.tasks.task_import_setup_process'
+)
+queue_importer.add_task_type(
+    label=_('Process an import setup item'),
+    dotted_path='importer.tasks.task_import_setup_item_process'
 )
 queue_importer.add_task_type(
     label=_('Populate the items of an import setup'),
